==> open-xchange-messaging-json_6.16.1.0.orig.tar.gz: open-xchange-messaging-json-6.16.1.0/src/com/openexchange/messaging/json/actions/messages/MessagingActionFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.json.actions.messages;

import java.util.HashMap;
import java.util.Map;
import com.openexchange.ajax.requesthandler.AJAXActionService;
import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
import com.openexchange.caching.Cache;
import com.openexchange.messaging.json.MessagingMessageParser;
import com.openexchange.messaging.json.MessagingMessageWriter;
import com.openexchange.messaging.registry.MessagingServiceRegistry;
import com.openexchange.tools.servlet.AjaxException;


/**
 * {@link MessagingActionFactory}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class MessagingActionFactory implements AJAXActionServiceFactory {

    public static MessagingActionFactory INSTANCE = null; // Initialized in Activator

    private Map<String, AJAXActionService> actions = null;
    
    
    public MessagingActionFactory(MessagingServiceRegistry registry, MessagingMessageWriter writer, MessagingMessageParser parser, Cache cache) {
        super();
        actions = new HashMap<String, AJAXActionService>();
        
        actions.put("all", new AllAction(registry, writer, parser, cache));
        actions.put("get", new GetAction(registry, writer, parser, cache));
        actions.put("list", new ListAction(registry, writer, parser, cache));
        actions.put("perform", new PerformAction(registry, writer, parser, cache));
        actions.put("send", new SendAction(registry, writer, parser, cache));
        actions.put("update", new UpdateAction(registry, writer, parser, cache));
        actions.put("updates", new UpdatesAction(registry, writer, parser, cache));
    } 
    
    public AJAXActionService createActionService(String action) throws AjaxException {
        return actions.get(action);
    }

}

==> open-xchange-messaging-json_6.18.0.0.orig.tar.gz: open-xchange-messaging-json-6.18.0.0/src/com/openexchange/messaging/json/actions/messages/MessagingActionFactory.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.json.actions.messages;

import java.util.HashMap;
import java.util.Map;
import com.openexchange.ajax.requesthandler.AJAXActionService;
import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
import com.openexchange.ajax.requesthandler.AJAXRequestData;
import com.openexchange.caching.Cache;
import com.openexchange.messaging.json.MessagingMessageParser;
import com.openexchange.messaging.json.MessagingMessageWriter;
import com.openexchange.messaging.registry.MessagingServiceRegistry;
import com.openexchange.session.Session;
import com.openexchange.tools.servlet.AjaxException;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link MessagingActionFactory}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class MessagingActionFactory implements AJAXActionServiceFactory {

    public static MessagingActionFactory INSTANCE = null; // Initialized in Activator

    private Map<String, AJAXActionService> actions = null;

    private Cache cache;

    private MessagingMessageParser parser;

    private MessagingMessageWriter writer;

    private MessagingServiceRegistry registry;
    
    
    public MessagingActionFactory(MessagingServiceRegistry registry, MessagingMessageWriter writer, MessagingMessageParser parser, Cache cache) {
        super();
        actions = new HashMap<String, AJAXActionService>();
        
        actions.put("all", new AllAction(registry, writer, parser, cache));
        actions.put("get", new GetAction(registry, writer, parser, cache));
        actions.put("list", new ListAction(registry, writer, parser, cache));
        actions.put("perform", new PerformAction(registry, writer, parser, cache));
        actions.put("send", new SendAction(registry, writer, parser, cache));
        actions.put("update", new UpdateAction(registry, writer, parser, cache));
        actions.put("updates", new UpdatesAction(registry, writer, parser, cache));
        
        this.writer = writer;
        this.parser = parser;
        this.cache = cache;
        this.registry = registry;
    } 
    
    public AJAXActionService createActionService(String action) throws AjaxException {
        return actions.get(action);
    }
    
    public MessagingRequestData wrapRequest(AJAXRequestData req, ServerSession session) {
        return new MessagingRequestData(req, session, registry, parser, cache);
    }

}
